@@ -1,7 +1,7 @@
 package Perinci::Sub::CoerceArgs;
 
 our $DATE = '2015-09-25'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -149,6 +149,8 @@ sub _coerce_to_datetime_duration {
 
     my $val = $args->{$arg_name};
 
+    my $d;
+
     if ($val =~ /\A\+?\d+(?:\.\d*)?\z/) {
         require DateTime::Duration;
         my $days = int($val/86400);
@@ -184,6 +186,18 @@ sub _coerce_to_datetime_duration {
             # no-op
             return [200];
         }
+    } elsif (eval { require Time::Duration::Parse::AsHash; $d = Time::Duration::Parse::AsHash::parse_duration($val) } && !$@) {
+        require DateTime::Duration;
+        $args->{$arg_name} = DateTime::Duration->new(
+            years   => $d->{years}   || 0,
+            months  => $d->{months}  || 0,
+            weeks   => $d->{weeks}   || 0,
+            days    => $d->{days}    || 0,
+            hours   => $d->{hours}   || 0,
+            minutes => $d->{minutes} || 0,
+            seconds => $d->{seconds} || 0,
+        );
+        return [200];
     }
 
     return [400, "Can't coerce '$arg_name' to DateTime::Duration object: " .
@@ -195,6 +209,8 @@ sub _coerce_to_secs {
 
     my $val = $args->{$arg_name};
 
+    my $d;
+
     if ($val =~ /\A\+?\d+(?:\.\d*)?\z/) {
         # no-op
         return [200];
@@ -221,9 +237,12 @@ sub _coerce_to_secs {
                 $min*60 + $s;
             return [200];
         }
+    } elsif (eval { require Time::Duration::Parse; $d = Time::Duration::Parse::parse_duration($val) } && !$@) {
+        $args->{$arg_name} = $d;
+        return [200];
     }
 
-    return [400, "Can't coerce '$arg_name' to DateTime::Duration object: " .
+    return [400, "Can't coerce '$arg_name' to seconds: " .
                 "'$args->{$arg_name}'"];
 }
 
@@ -346,7 +365,7 @@ Perinci::Sub::CoerceArgs - Coerce arguments
 
 =head1 VERSION
 
-This document describes version 0.07 of Perinci::Sub::CoerceArgs (from Perl distribution Perinci-Sub-CoerceArgs), released on 2015-09-25.
+This document describes version 0.08 of Perinci::Sub::CoerceArgs (from Perl distribution Perinci-Sub-CoerceArgs), released on 2015-09-25.
 
 =head1 SYNOPSIS
 
@@ -359,18 +378,6 @@ This document describes version 0.07 of Perinci::Sub::CoerceArgs (from Perl dist
 I expect this to be a temporary solution until L<Data::Sah> or
 L<Perinci::Sub::Wrapper> has this functionality.
 
-Some notes:
-
-=over
-
-=item *
-
-For convenience, when converting duration larger than 86400 from seconds (e.g.
-864000) into L<DateTime::Duration> object, C<days> and C<seconds> will be used
-instead of just C<seconds> (i.e., we disregard leap seconds).
-
-=back
-
 =head1 FUNCTIONS
 
 
